# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'browser_layout.ui'
#
# Created by: PyQt5 UI code generator 5.14.1
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(765, 484)
        Form.setStyleSheet("")
        self.gridLayout = QtWidgets.QGridLayout(Form)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setSpacing(0)
        self.gridLayout.setObjectName("gridLayout")
        self.listWidget = QtWidgets.QListWidget(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.listWidget.sizePolicy().hasHeightForWidth())
        self.listWidget.setSizePolicy(sizePolicy)
        self.listWidget.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.listWidget.setDragEnabled(True)
        self.listWidget.setIconSize(QtCore.QSize(140, 80))
        self.listWidget.setTextElideMode(QtCore.Qt.ElideMiddle)
        self.listWidget.setVerticalScrollMode(QtWidgets.QAbstractItemView.ScrollPerPixel)
        self.listWidget.setHorizontalScrollMode(QtWidgets.QAbstractItemView.ScrollPerPixel)
        self.listWidget.setMovement(QtWidgets.QListView.Static)
        self.listWidget.setResizeMode(QtWidgets.QListView.Adjust)
        self.listWidget.setLayoutMode(QtWidgets.QListView.SinglePass)
        self.listWidget.setGridSize(QtCore.QSize(150, 100))
        self.listWidget.setViewMode(QtWidgets.QListView.IconMode)
        self.listWidget.setUniformItemSizes(True)
        self.listWidget.setSelectionRectVisible(False)
        self.listWidget.setObjectName("listWidget")
        self.gridLayout.addWidget(self.listWidget, 2, 0, 1, 1)
        self.frame = QtWidgets.QFrame(Form)
        self.frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.frame)
        self.gridLayout_2.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_2.setHorizontalSpacing(2)
        self.gridLayout_2.setVerticalSpacing(1)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.label = QtWidgets.QLabel(self.frame)
        self.label.setObjectName("label")
        self.gridLayout_2.addWidget(self.label, 0, 0, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem, 0, 1, 1, 1)
        self.gridLayout.addWidget(self.frame, 0, 0, 1, 2)
        self.comments = QtWidgets.QTextBrowser(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comments.sizePolicy().hasHeightForWidth())
        self.comments.setSizePolicy(sizePolicy)
        self.comments.setMinimumSize(QtCore.QSize(0, 0))
        self.comments.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.comments.setLineWrapMode(QtWidgets.QTextEdit.NoWrap)
        self.comments.setOpenLinks(False)
        self.comments.setObjectName("comments")
        self.gridLayout.addWidget(self.comments, 2, 1, 1, 1)

        self.retranslateUi(Form)
        self.listWidget.itemClicked['QListWidgetItem*'].connect(Form.itemClicked)
        self.listWidget.itemDoubleClicked['QListWidgetItem*'].connect(Form.itemDoubleClicked)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.frame.setProperty("class", _translate("Form", "deep"))
        self.label.setText(_translate("Form", "Double click to launch any experiment"))
        self.comments.setHtml(_translate("Form", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Ubuntu\'; font-size:11pt; font-weight:400; font-style:normal;\">\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:10pt;\"><br /></p></body></html>"))
from . import res_rc



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'screenshot.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(680, 543)
        self.verticalLayout = QtWidgets.QVBoxLayout(Dialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.imgFrame = QtWidgets.QFrame(Dialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(3)
        sizePolicy.setHeightForWidth(self.imgFrame.sizePolicy().hasHeightForWidth())
        self.imgFrame.setSizePolicy(sizePolicy)
        self.imgFrame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.imgFrame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.imgFrame.setObjectName("imgFrame")
        self.verticalLayout.addWidget(self.imgFrame)
        self.frame = QtWidgets.QFrame(Dialog)
        self.frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.gridLayout = QtWidgets.QGridLayout(self.frame)
        self.gridLayout.setObjectName("gridLayout")
        self.pathEdit = QtWidgets.QLineEdit(self.frame)
        self.pathEdit.setObjectName("pathEdit")
        self.gridLayout.addWidget(self.pathEdit, 0, 2, 1, 1)
        self.translationLabel = QtWidgets.QLabel(self.frame)
        self.translationLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.translationLabel.setObjectName("translationLabel")
        self.gridLayout.addWidget(self.translationLabel, 1, 0, 1, 1)
        self.langEdit = QtWidgets.QLineEdit(self.frame)
        self.langEdit.setObjectName("langEdit")
        self.gridLayout.addWidget(self.langEdit, 1, 2, 1, 1)
        self.pathLabel = QtWidgets.QLabel(self.frame)
        self.pathLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.pathLabel.setObjectName("pathLabel")
        self.gridLayout.addWidget(self.pathLabel, 0, 0, 1, 1)
        self.widthCheckBox = QtWidgets.QCheckBox(self.frame)
        self.widthCheckBox.setChecked(True)
        self.widthCheckBox.setObjectName("widthCheckBox")
        self.gridLayout.addWidget(self.widthCheckBox, 2, 0, 1, 1)
        self.widthSpinBox = QtWidgets.QSpinBox(self.frame)
        self.widthSpinBox.setMaximum(1000)
        self.widthSpinBox.setSingleStep(10)
        self.widthSpinBox.setProperty("value", 400)
        self.widthSpinBox.setObjectName("widthSpinBox")
        self.gridLayout.addWidget(self.widthSpinBox, 2, 2, 1, 1)
        self.verticalLayout.addWidget(self.frame)
        self.buttonBox = QtWidgets.QDialogButtonBox(Dialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Help|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(Dialog)
        self.buttonBox.accepted.connect(Dialog.accept)
        self.buttonBox.rejected.connect(Dialog.reject)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Screnshot"))
        self.translationLabel.setText(_translate("Dialog", "Translations ="))
        self.pathLabel.setText(_translate("Dialog", "Path ="))
        self.widthCheckBox.setText(_translate("Dialog", "PNG, width ="))




import eyes17.eyes
p = eyes17.eyes.open()

from pylab import *

p.set_sine(200)
p.set_pv1(1.7)       # will clamp at 2.0 + diode drop

maxV = 8

p.select_range('A1', maxV)
p.select_range('A2', maxV)

t,v, tt,vv = p.capture2(500, 20)   # captures A1 and A2

xlabel('Time(mS)')
ylabel('Voltage(V)')
plot([0,10], [0,0], 'black')
ylim([-maxV, maxV])

plot(t,v,linewidth = 2, color = 'blue', label='Input')
plot(tt, vv, linewidth = 2, color = 'red', label='Clamped')

legend(framealpha=0.5)

show()



import sys, time, math, os.path
from . import utils

from .QtVersion import *

from .layouts import ui_browser_layout

electronicsExpts = [ 
[QT_TRANSLATE_NOOP('MainWindow','Diode Characteristics'),('3.13','diodeIV','pics','diode-iv-screen.png')],
[QT_TRANSLATE_NOOP('MainWindow','Logic Gates'),('3.11','logic-gates','pics','ic555-screen.png')],
[QT_TRANSLATE_NOOP('MainWindow','NPN Output Characteristics'),('3.14','npnCEout','pics','transistor-ce-config.png')],
[QT_TRANSLATE_NOOP('MainWindow','RLC Steady state response'),('4.3','RLCsteadystate','pics','RLCsteadystate-screen.png')],
[QT_TRANSLATE_NOOP('MainWindow','RC Transient response'),('4.4','RCtransient','pics','RLCtransient-screen.png')],
[QT_TRANSLATE_NOOP('MainWindow','Fullwave Rectifier'), ('8.9','fullwave','pics','fullwave-filter-screen.png')]
]


class Expt(QtWidgets.QWidget, ui_browser_layout.Ui_Form):
	def __init__(self, device=None):
		super(Expt, self).__init__()
		self.setupUi(self)
		self.thumbList = {}

		self.p = device										# connection to the device hardware 
		for ex in electronicsExpts:
			fname = ex[1][1]
			helpPath = os.path.join(os.path.dirname(os.path.abspath(__file__)),'helpFiles',lang[:2],ex[1][0]+'.html')
			thumbpath = os.path.join(os.path.dirname(os.path.abspath(__file__)),'helpFiles' , lang[:2] ,ex[1][2], ex[1][3])
			print(ex,helpPath)
			x = QtGui.QIcon(thumbpath)
			a = QtGui.QListWidgetItem(x,fname)
			self.listWidget.addItem(a)
			self.thumbList[fname] = [a,helpPath]

		print(self.thumbList)

	def itemDoubleClicked(self,sel):
		fname = self.thumbList[str(sel.text())][1]
		print('2',fname)

	def itemClicked(self,sel):
		fname = self.thumbList[str(sel.text())][1]
		print(fname)

		with open(fname) as f:
				self.comments.setHtml(f.read())


	def msg(self, m):
		self.msgwin.setText(self.tr(m))
		

if __name__ == '__main__':
	from . eyes17 import eyes
	dev = eyes17.eyes.open()
	app = QApplication(sys.argv)

	# translation stuff
	lang=QLocale.system().name()
	t=QTranslator()
	t.load("lang/"+lang, os.path.dirname(__file__))
	app.installTranslator(t)
	t1=QTranslator()
	t1.load("qt_"+lang,
	        QLibraryInfo.location(QLibraryInfo.TranslationsPath))
	app.installTranslator(t1)

	mw = Expt(dev)
	mw.show()
	sys.exit(app.exec_())
	
